Kafka Client for VELI.STORE

Description
This module helps you to have a base class of Integrator and CRUDIntegrator, 
which are used to connect to third-party service providers.

Integrator Base class provide request validation posting data in different services, 
CRUDIntegrator helps to create, read, update and delete objects in third-party services.

There are also handler Base class, for handling data before sending it. you can find it in handler.py

feel free to use it.

